package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.proprietorHouse.ProprietorHouse;

import java.util.List;


/**
 * 业主房屋管理Mapper接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface ProprietorHouseMapper 
{
    /**
     * 查询业主房屋管理
     * 
     * @param proprietorId 业主房屋管理主键
     * @return 业主房屋管理
     */
    public ProprietorHouse selectProprietorHouseByProprietorId(Long proprietorId);

    /**
     * 查询业主房屋管理列表
     * 
     * @param proprietorHouse 业主房屋管理
     * @return 业主房屋管理集合
     */
    public List<ProprietorHouse> selectProprietorHouseList(ProprietorHouse proprietorHouse);

    /**
     * 新增业主房屋管理
     * 
     * @param proprietorHouse 业主房屋管理
     * @return 结果
     */
    public int insertProprietorHouse(ProprietorHouse proprietorHouse);

    /**
     * 修改业主房屋管理
     * 
     * @param proprietorHouse 业主房屋管理
     * @return 结果
     */
    public int updateProprietorHouse(ProprietorHouse proprietorHouse);

    /**
     * 删除业主房屋管理
     * 
     * @param proprietorId 业主房屋管理主键
     * @return 结果
     */
    public int deleteProprietorHouseByProprietorId(Long proprietorId);

    /**
     * 批量删除业主房屋管理
     * 
     * @param proprietorIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProprietorHouseByProprietorIds(Long[] proprietorIds);
}
